pub enum Sig {
Alrm,
Chld,
Hup,
Int,
Io,
Pipe,
Quit,
Term,
Usr1,
Usr2,
}Expand description
A Unix signal for triggering graceful shutdown.
Each variant corresponds to a Unix process signal which can be used to
trigger a graceful shutdown. See Shutdown for details.
(De)serialization
A Sig variant serializes and deserializes as a lowercase string equal to
the name of the variant: "alrm" for Sig::Alrm, "chld" for
Sig::Chld, and so on.
Variants
Alrm
The SIGALRM Unix signal.
Chld
The SIGCHLD Unix signal.
Hup
The SIGHUP Unix signal.
Int
The SIGINT Unix signal.
Io
The SIGIO Unix signal.
Pipe
The SIGPIPE Unix signal.
Quit
The SIGQUIT Unix signal.
Term
The SIGTERM Unix signal.
Usr1
The SIGUSR1 Unix signal.
Usr2
The SIGUSR2 Unix signal.