Chain

Struct Chain 

pub struct Chain<T, U> { /* private fields */ }
Reader for the chain method.

Implementations

Source

impl<T, U> Chain<T, U>
where T: AsyncRead, U: AsyncRead,

pub fn get_ref(&self) -> (&T, &U)

Gets references to the underlying readers in this Chain.

pub fn get_mut(&mut self) -> (&mut T, &mut U)

Gets mutable references to the underlying readers in this Chain.

Care should be taken to avoid modifying the internal I/O state of the underlying readers as doing so may corrupt the internal state of this Chain.

pub fn get_pin_mut(self: Pin<&mut Chain<T, U>>) -> (Pin<&mut T>, Pin<&mut U>)

Gets pinned mutable references to the underlying readers in this Chain.

Care should be taken to avoid modifying the internal I/O state of the underlying readers as doing so may corrupt the internal state of this Chain.

pub fn into_inner(self) -> (T, U)

Consumes the Chain, returning the wrapped readers.