pub struct GrowerTreeConfiguration { /* private fields */ }Expand description
We set the GrowerTreeConfiguration to refine the shape of our model trees:
- Depth: # of hierarchical levels (≥1)
- Breadth: baseline sibling count (≥1)
- Density: variants at leaves (≥1)
- leaf_granularity: fraction [0..1] controlling fine detail at leaves
- balance_symmetry: fraction [0..1] controlling symmetrical vs. varied structure
- complexity: overall complexity level (simple, balanced, or complex)
Optional advanced sub-structs:
- level_specific: arrays of breadth/density overrides for each level
- weighted_branching: mean ± variance approach
- level_skipping: per-level leaf probabilities
- capstone: highlight nodes (off, single, or fraction)
- ordering: sub-branch sorting approach
- ai_confidence: modifies branch factor based on AI certainty
New fields:
- aggregator_preference: fraction [0..1] controlling how often aggregator is used vs. dispatch
- allow_early_leaves: if true, allows leaf nodes to appear before the final depth
- partial_subbranch_probability: fraction [0..1] controlling how often each child sub-branch is included
- tree_expansion_policy: advanced logic for picking among aggregator/dispatch/leaf
- aggregator_depth_limit, dispatch_depth_limit, leaf_min_depth: optional constraints on usage of aggregator, dispatch, or leaf nodes by depth
Your justification must indicate why each justified parameter value was chosen deliberately by using knowledge and an understanding of the target domain as a guide. Since each target domain is different, the trees which map them will have different shapes and different GrowerTreeConfiguration parameters. Your job during justification is to explain clearly why a given parameter setting makes sense in the provided target domain.
Implementations
Sourceimpl GrowerTreeConfiguration
impl GrowerTreeConfiguration
Sourcepub fn base_config(
depth: u8,
breadth: u8,
density: u8,
) -> GrowerTreeConfiguration
pub fn base_config( depth: u8, breadth: u8, density: u8, ) -> GrowerTreeConfiguration
Creates a minimal config with the given core fields.
Sourcepub fn to_builder(&self) -> GrowerTreeConfigurationBuilder
pub fn to_builder(&self) -> GrowerTreeConfigurationBuilder
Convert the existing config into a builder, copying all fields.
Sourcepub fn with_ai_conf(
self,
base_factor: u8,
factor_multiplier: f32,
) -> GrowerTreeConfiguration
pub fn with_ai_conf( self, base_factor: u8, factor_multiplier: f32, ) -> GrowerTreeConfiguration
Attaches an AI-confidence sub-struct, returning a new config.
Sourcepub fn with_weighted_branching(
self,
mean: u8,
variance: u8,
) -> GrowerTreeConfiguration
pub fn with_weighted_branching( self, mean: u8, variance: u8, ) -> GrowerTreeConfiguration
Attaches WeightedBranching with the given mean/variance.
Sourcepub fn with_level_skipping(
self,
skip_probs: Vec<f32>,
) -> GrowerTreeConfiguration
pub fn with_level_skipping( self, skip_probs: Vec<f32>, ) -> GrowerTreeConfiguration
Attaches LevelSkipping with the given skip probabilities.
Sourcepub fn with_level_specific(
self,
bpl: Vec<u8>,
dpl: Vec<u8>,
) -> GrowerTreeConfiguration
pub fn with_level_specific( self, bpl: Vec<u8>, dpl: Vec<u8>, ) -> GrowerTreeConfiguration
Attaches LevelSpecific with the given breadth/density arrays.
Sourcepub fn with_capstone(
self,
mode: CapstoneMode,
prob: f32,
) -> GrowerTreeConfiguration
pub fn with_capstone( self, mode: CapstoneMode, prob: f32, ) -> GrowerTreeConfiguration
Attaches a Capstone sub-struct with the given mode/prob.
Sourceimpl GrowerTreeConfiguration
impl GrowerTreeConfiguration
Sourcepub fn target_name(&self) -> &String
pub fn target_name(&self) -> &String
This field holds verbatim the lower-kebab-case target-name belonging to the tree grow process.
Sourcepub fn depth(&self) -> &u8
pub fn depth(&self) -> &u8
Set this integer to define how many levels exist from root to leaf in the tree (≥5).
- Setting a higher number → deeper specialization (depth).
- Setting a lower number → simpler, more general modeling.
Sourcepub fn breadth(&self) -> &u8
pub fn breadth(&self) -> &u8
Set this integer to define how many siblings or sub-branches each node has by default (≥7).
- Higher → broad coverage, e.g. “Spread (Loosen).”
- Lower → narrower, e.g. “Narrow (Tighten).”
Sourcepub fn density(&self) -> &u8
pub fn density(&self) -> &u8
Set this integer to define how many variants (children) each leaf node holds by default (≥9).
- Higher → more fullness (“Dense”).
- Lower → sparser representation (“Sparse”).
Sourcepub fn leaf_granularity(&self) -> &f32
pub fn leaf_granularity(&self) -> &f32
Set this fraction [0..1] to specify how finely detailed each leaf item becomes.
- 0 = coarse (broad, less specialized leaves),
- 1 = extremely specific leaves.
Sourcepub fn balance_symmetry(&self) -> &f32
pub fn balance_symmetry(&self) -> &f32
Set this fraction [0..1] to numerically characerize the symmetrical vs. unbalanced structure of our tree.
- 0.0 = random/unbalanced,
- 1.0 = perfectly balanced.
Sourcepub fn complexity(&self) -> &ConfigurationComplexity
pub fn complexity(&self) -> &ConfigurationComplexity
Set this field to select between “simple”, “balanced”, or “complex” for overall usage patterns.
Sourcepub fn level_specific(&self) -> &Option<TreeLevelSpecificConfiguration>
pub fn level_specific(&self) -> &Option<TreeLevelSpecificConfiguration>
Set this optional sub-struct to specify the arrays for per-level breadth & density overrides.
Sourcepub fn weighted_branching(&self) -> &Option<WeightedBranchingConfiguration>
pub fn weighted_branching(&self) -> &Option<WeightedBranchingConfiguration>
Set this optional sub-struct to define mean ± variance if you want random branching factors.
Sourcepub fn level_skipping(&self) -> &Option<LevelSkippingConfiguration>
pub fn level_skipping(&self) -> &Option<LevelSkippingConfiguration>
Set this optional sub-struct to define probabilities for skipping deeper expansions at certain levels.
Sourcepub fn capstone(&self) -> &Option<CapstoneGenerationConfiguration>
pub fn capstone(&self) -> &Option<CapstoneGenerationConfiguration>
Set this optional sub-struct to define the characteristics of capstone leaves, how many of them there are, and our chances of encountering one at any given level.
Sourcepub fn ordering(&self) -> &Option<SubBranchOrdering>
pub fn ordering(&self) -> &Option<SubBranchOrdering>
Set this optional sub-struct to define how sub-branches get ordered (alphabetical, difficulty, random).
Sourcepub fn ai_confidence(&self) -> &Option<AiTreeBranchingConfidenceConfiguration>
pub fn ai_confidence(&self) -> &Option<AiTreeBranchingConfidenceConfiguration>
Set this optional sub-struct to define how AI confidence modifies branch factor (if any).
Sourcepub fn aggregator_preference(&self) -> &f32
pub fn aggregator_preference(&self) -> &f32
Set this fraction [0..1] to control how often aggregator nodes are used vs. dispatch nodes at intermediate levels.
- 0.0 => always dispatch
- 1.0 => always aggregator
- 0.5 => half aggregator, half dispatch
This is a simplistic alternative to tree_expansion_policy. If tree_expansion_policy is set to something
more advanced, this field might be ignored or used as a fallback.
Sourcepub fn allow_early_leaves(&self) -> &bool
pub fn allow_early_leaves(&self) -> &bool
If true, leaf nodes may appear before the final depth, i.e. some sub-branches might terminate
early with a LeafHolder.
If false, all leaves appear exactly at depth.
Sourcepub fn partial_subbranch_probability(&self) -> &f32
pub fn partial_subbranch_probability(&self) -> &f32
Fraction [0..1] controlling how often each potential child sub-branch is included.
- 0.0 => no optional sub-branches
- 1.0 => all sub-branches are included
This might tie into ChildSpec optional or probability fields, e.g. randomizing
which children appear.
Sourcepub fn tree_expansion_policy(&self) -> &TreeExpansionPolicy
pub fn tree_expansion_policy(&self) -> &TreeExpansionPolicy
An advanced enum describing how to pick among Dispatch, Aggregate, or LeafHolder
at each level.
- If you set this to
NodeVariantStrategy::Simple, you get a straightforward approach where we do dispatch at intermediate nodes and leaves at final depth. - If you use
Weighted, you can do random picks among aggregator/dispatch/leaf. - If you do
DepthBased, you can specify exactly which level to start aggregator vs. leaf.
Sourcepub fn aggregator_depth_limit(&self) -> &Option<u8>
pub fn aggregator_depth_limit(&self) -> &Option<u8>
If set, aggregator nodes will not appear deeper than this level.
If None, no limit.
If Some(n), aggregator variant is disallowed for levels > n.
Sourcepub fn dispatch_depth_limit(&self) -> &Option<u8>
pub fn dispatch_depth_limit(&self) -> &Option<u8>
If set, dispatch nodes will not appear deeper than this level.
If None, no limit.
If Some(n), dispatch variant is disallowed for levels > n.
Sourcepub fn leaf_min_depth(&self) -> &Option<u8>
pub fn leaf_min_depth(&self) -> &Option<u8>
If set, leaf-holder nodes cannot appear before this level (forces deeper expansions).
If None, no minimum.
If Some(n), we skip leaf-holder variants until level ≥ n.
Sourceimpl GrowerTreeConfiguration
impl GrowerTreeConfiguration
Sourcepub fn validate(&self) -> Result<(), GrowerTreeConfigurationError>
pub fn validate(&self) -> Result<(), GrowerTreeConfigurationError>
This function should validate all fields: baseline parameters and each advanced sub-struct if present. Returns an error if any invalid configuration is detected.
Sourcepub fn from_toml_str(
s: &str,
) -> Result<GrowerTreeConfiguration, GrowerTreeConfigurationError>
pub fn from_toml_str( s: &str, ) -> Result<GrowerTreeConfiguration, GrowerTreeConfigurationError>
This function should parse a GrowerTreeConfiguration from TOML string input.
Sourcepub fn to_toml_string(&self) -> Result<String, GrowerTreeConfigurationError>
pub fn to_toml_string(&self) -> Result<String, GrowerTreeConfigurationError>
This function should convert the GrowerTreeConfiguration into a pretty TOML string.
Sourcepub fn from_toml_file<P>(
path: P,
) -> Result<GrowerTreeConfiguration, GrowerTreeConfigurationError>
pub fn from_toml_file<P>( path: P, ) -> Result<GrowerTreeConfiguration, GrowerTreeConfigurationError>
This function should load a GrowerTreeConfiguration from a TOML file on disk.
Sourcepub fn to_toml_file<P>(
&self,
path: P,
) -> Result<(), GrowerTreeConfigurationError>
pub fn to_toml_file<P>( &self, path: P, ) -> Result<(), GrowerTreeConfigurationError>
This function should write the GrowerTreeConfiguration to a file in TOML format.